/*
 * Created on October 2nd 2023
 *
 * Copyright (C) 2023 Welltested AI - All Rights Reserved
 * The code in this file is Intellectutal Property of Welltested AI.
 * and can't be edited, redistributed or used without a valid license of it's product (Welltested)[https://welltested.ai]
 */
import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:welltested/src/models/session_result.dart';
import 'package:welltested/src/models/user_info.dart';
import 'package:welltested/src/utilities/env_parser.dart';

class UserRepository {
  final _baseUrl = 'https://api.welltested.ai';

  Future<UserInfo> getUserInfo() async {
    try {
      final env = DotEnv(includePlatformEnvironment: true)..load();
      final apiKey = env.getOrElse('WELLTESTED_API', () => '');
      if (apiKey.isEmpty) {
        throw '🚨 WELLTESTED_API key not found. Please refer documentation for more Info.';
      }

      final response = await http
          .get(Uri.parse('$_baseUrl/user/info'), headers: {'apikey': apiKey});
      if (response.statusCode == 401) {
        throw "🚨 Invalid Welltested API Key. Use the key recieved in the registered mail.";
      } else if (response.statusCode == 500) {
        throw "🚨 Internal Server Error: ${response.body}";
      } else if (response.statusCode != 200) {
        throw SocketException("Server Error");
      } else
        return UserInfo.fromJson(jsonDecode(response.body));
    } catch (e) {
      throw e;
    }
  }

  Future<SessionResult> getSessionInfo(String command) async {
    try {
      final env = DotEnv(includePlatformEnvironment: true)..load();
      final apiKey = env.getOrElse('WELLTESTED_API', () => '');
      if (apiKey.isEmpty) {
        throw '🚨 WELLTESTED_API key not found. Please refer documentation for more Info.';
      }
      final body = {'command': command};
      final response = await http.post(Uri.parse('$_baseUrl/user/session'),
          body: body, headers: {'apikey': apiKey});
      if (response.statusCode == 401) {
        throw "🚨 Invalid Welltested API Key. Use the key recieved in the registered mail.";
      } else if (response.statusCode == 500) {
        throw "🚨 Internal Server Error: ${response.body}";
      } else if (response.statusCode != 200) {
        throw SocketException("Server Error");
      } else
        return SessionResult.fromJson(jsonDecode(response.body));
    } catch (e) {
      throw e;
    }
  }
}
